@@ -24,6 +24,7 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef HAVE_STRUCT_OSOCKADDR
+#undef LIBGTOP_PACKAGE
 #undef PACKAGE
 #undef VERSION
 #undef HAVE_LIBSM
@@ -128,6 +129,8 @@
 #undef ssize_t
 #undef u_int64_t
 #undef int64_t
+#undef u_int8_t
+#undef int8_t
 
 #undef HAVE_GLIBTOP_MACHINE_H
 
@@ -173,3 +176,7 @@
 /* Define if you have the libxml library */
 #undef HAVE_LIBXML
 
+/* Modem lockfile for PPP support. This is a printf-like format string
+ * which takes the interface number as argument
+ * (default '/var/lock/LCK..ttyS%u'). */
+#undef LIBGTOP_MODEM_LOCKFILE
