@@ -13,6 +13,8 @@
 #include <glibtop-backend-private.h>
 #include "server.h"
 
+#if GLIBTOP_SUID_CPU
+
 static int
 _glibtop_demarshal_cpu_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -55,6 +57,11 @@ _glibtop_demarshal_cpu_i (glibtop *server, glibtop_backend *backend, const void
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_CPU */
+
+
+#if GLIBTOP_SUID_MEM
+
 static int
 _glibtop_demarshal_mem_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -97,6 +104,11 @@ _glibtop_demarshal_mem_i (glibtop *server, glibtop_backend *backend, const void
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_MEM */
+
+
+#if GLIBTOP_SUID_SWAP
+
 static int
 _glibtop_demarshal_swap_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -139,6 +151,11 @@ _glibtop_demarshal_swap_i (glibtop *server, glibtop_backend *backend, const void
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_SWAP */
+
+
+#if GLIBTOP_SUID_UPTIME
+
 static int
 _glibtop_demarshal_uptime_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -181,6 +198,11 @@ _glibtop_demarshal_uptime_i (glibtop *server, glibtop_backend *backend, const vo
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_UPTIME */
+
+
+#if GLIBTOP_SUID_LOADAVG
+
 static int
 _glibtop_demarshal_loadavg_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -223,6 +245,11 @@ _glibtop_demarshal_loadavg_i (glibtop *server, glibtop_backend *backend, const v
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_LOADAVG */
+
+
+#if GLIBTOP_SUID_SHM_LIMITS
+
 static int
 _glibtop_demarshal_shm_limits_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -265,6 +292,11 @@ _glibtop_demarshal_shm_limits_i (glibtop *server, glibtop_backend *backend, cons
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_SHM_LIMITS */
+
+
+#if GLIBTOP_SUID_MSG_LIMITS
+
 static int
 _glibtop_demarshal_msg_limits_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -307,6 +339,11 @@ _glibtop_demarshal_msg_limits_i (glibtop *server, glibtop_backend *backend, cons
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_MSG_LIMITS */
+
+
+#if GLIBTOP_SUID_SEM_LIMITS
+
 static int
 _glibtop_demarshal_sem_limits_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -349,6 +386,11 @@ _glibtop_demarshal_sem_limits_i (glibtop *server, glibtop_backend *backend, cons
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_SEM_LIMITS */
+
+
+#if GLIBTOP_SUID_PROCLIST
+
 static int
 _glibtop_demarshal_proclist_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -411,6 +453,11 @@ _glibtop_demarshal_proclist_i (glibtop *server, glibtop_backend *backend, const
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROCLIST */
+
+
+#if GLIBTOP_SUID_PROC_STATE
+
 static int
 _glibtop_demarshal_proc_state_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -461,6 +508,11 @@ _glibtop_demarshal_proc_state_i (glibtop *server, glibtop_backend *backend, cons
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_STATE */
+
+
+#if GLIBTOP_SUID_PROC_UID
+
 static int
 _glibtop_demarshal_proc_uid_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -511,6 +563,11 @@ _glibtop_demarshal_proc_uid_i (glibtop *server, glibtop_backend *backend, const
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_UID */
+
+
+#if GLIBTOP_SUID_PROC_MEM
+
 static int
 _glibtop_demarshal_proc_mem_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -561,6 +618,11 @@ _glibtop_demarshal_proc_mem_i (glibtop *server, glibtop_backend *backend, const
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_MEM */
+
+
+#if GLIBTOP_SUID_PROC_TIME
+
 static int
 _glibtop_demarshal_proc_time_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -611,6 +673,11 @@ _glibtop_demarshal_proc_time_i (glibtop *server, glibtop_backend *backend, const
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_TIME */
+
+
+#if GLIBTOP_SUID_PROC_SIGNAL
+
 static int
 _glibtop_demarshal_proc_signal_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -661,6 +728,11 @@ _glibtop_demarshal_proc_signal_i (glibtop *server, glibtop_backend *backend, con
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_SIGNAL */
+
+
+#if GLIBTOP_SUID_PROC_KERNEL
+
 static int
 _glibtop_demarshal_proc_kernel_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -711,6 +783,11 @@ _glibtop_demarshal_proc_kernel_i (glibtop *server, glibtop_backend *backend, con
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_KERNEL */
+
+
+#if GLIBTOP_SUID_PROC_SEGMENT
+
 static int
 _glibtop_demarshal_proc_segment_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -761,6 +838,11 @@ _glibtop_demarshal_proc_segment_i (glibtop *server, glibtop_backend *backend, co
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_SEGMENT */
+
+
+#if GLIBTOP_SUID_PROC_ARGS
+
 static int
 _glibtop_demarshal_proc_args_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -853,6 +935,11 @@ _glibtop_demarshal_proc_args_i (glibtop *server, glibtop_backend *backend, const
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_ARGS */
+
+
+#if GLIBTOP_SUID_PROC_MAP
+
 static int
 _glibtop_demarshal_proc_map_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -909,6 +996,11 @@ _glibtop_demarshal_proc_map_i (glibtop *server, glibtop_backend *backend, const
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PROC_MAP */
+
+
+#if GLIBTOP_SUID_INTERFACE_NAMES
+
 static int
 _glibtop_demarshal_interface_names_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -983,6 +1075,11 @@ _glibtop_demarshal_interface_names_i (glibtop *server, glibtop_backend *backend,
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_INTERFACE_NAMES */
+
+
+#if GLIBTOP_SUID_NETINFO
+
 static int
 _glibtop_demarshal_netinfo_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -991,9 +1088,10 @@ _glibtop_demarshal_netinfo_i (glibtop *server, glibtop_backend *backend, const v
 	char *_LIBGTOP_RECV_buf, *_LIBGTOP_RECV_ptr;
 	const char *_LIBGTOP_SEND_ptr;
 	glibtop_netinfo netinfo;
-	int retval = (int) 0;
+	glibtop_ifaddr * retval = (glibtop_ifaddr *) 0;
 	const char * _LIBGTOP_demarshal_interface;
-	unsigned _LIBGTOP_demarshal_transport;
+	u_int64_t _LIBGTOP_demarshal_transport;
+	glibtop_array array;
 	size_t _LIBGTOP_TEMP_len;
 	size_t _LIBGTOP_DATA_len;
 	off_t _LIBGTOP_DATA_offset;
@@ -1004,7 +1102,7 @@ _glibtop_demarshal_netinfo_i (glibtop *server, glibtop_backend *backend, const v
 	_LIBGTOP_SEND_offset = 0;
 	_LIBGTOP_SEND_ptr = (char *) send_ptr;
 	memset (&_LIBGTOP_demarshal_interface, 0, sizeof (const char *));
-	memset (&_LIBGTOP_demarshal_transport, 0, sizeof (unsigned));
+	memset (&_LIBGTOP_demarshal_transport, 0, sizeof (u_int64_t));
 	_LIBGTOP_DATA_len = 0;
 	_LIBGTOP_DATA_offset = 0;
 	_LIBGTOP_DATA_ptr = (char *) data_ptr;
@@ -1012,12 +1110,13 @@ _glibtop_demarshal_netinfo_i (glibtop *server, glibtop_backend *backend, const v
 	/* send size */
 	_LIBGTOP_SEND_len = 0;
 	_LIBGTOP_SEND_len += sizeof (size_t);
-	_LIBGTOP_SEND_len += sizeof (unsigned);
+	_LIBGTOP_SEND_len += sizeof (u_int64_t);
 	if (_LIBGTOP_SEND_len != send_size)
 		return -GLIBTOP_ERROR_DEMARSHAL_ERROR;
 
 	/* recv size */
 	_LIBGTOP_RECV_len = 0;
+	_LIBGTOP_RECV_len += sizeof (glibtop_array);
 	_LIBGTOP_RECV_len += sizeof (glibtop_netinfo);
 
 	/* recv buffer */
@@ -1036,23 +1135,35 @@ _glibtop_demarshal_netinfo_i (glibtop *server, glibtop_backend *backend, const v
 	*(_LIBGTOP_DATA_ptr + _LIBGTOP_TEMP_len) = 0;
 	_LIBGTOP_SEND_offset += sizeof (size_t);
 	_LIBGTOP_SEND_ptr = (char *) send_ptr + _LIBGTOP_SEND_offset;
-	memcpy (&_LIBGTOP_demarshal_transport, _LIBGTOP_SEND_ptr, sizeof (unsigned));
-	_LIBGTOP_SEND_offset += sizeof (unsigned);
+	memcpy (&_LIBGTOP_demarshal_transport, _LIBGTOP_SEND_ptr, sizeof (u_int64_t));
+	_LIBGTOP_SEND_offset += sizeof (u_int64_t);
 
-	retval = glibtop_get_netinfo_p (server, &netinfo, _LIBGTOP_demarshal_interface, _LIBGTOP_demarshal_transport);
+	retval = glibtop_get_netinfo_p (server, &array, &netinfo, _LIBGTOP_demarshal_interface, _LIBGTOP_demarshal_transport);
 	if (retval_ptr)
-		*retval_ptr = retval;
+		*retval_ptr = server->glibtop_errno;
 
 	/* write recv buffer */
+	memcpy (_LIBGTOP_RECV_ptr, &array, sizeof (glibtop_array));
+	_LIBGTOP_RECV_ptr += sizeof (glibtop_array);
 	memcpy (_LIBGTOP_RECV_ptr, &netinfo, sizeof (glibtop_netinfo));
 	_LIBGTOP_RECV_ptr += sizeof (glibtop_netinfo);
 
 	*recv_buf_ptr = _LIBGTOP_RECV_buf;
 	*recv_size_ptr = _LIBGTOP_RECV_len;
 
+	if (recv_data_ptr) {
+		*recv_data_ptr = retval;
+		*recv_data_size_ptr = array.total;
+	}
+
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_NETINFO */
+
+
+#if GLIBTOP_SUID_NETLOAD
+
 static int
 _glibtop_demarshal_netload_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -1129,6 +1240,11 @@ _glibtop_demarshal_netload_i (glibtop *server, glibtop_backend *backend, const v
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_NETLOAD */
+
+
+#if GLIBTOP_SUID_PPP
+
 static int
 _glibtop_demarshal_ppp_i (glibtop *server, glibtop_backend *backend, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
@@ -1139,16 +1255,19 @@ _glibtop_demarshal_ppp_i (glibtop *server, glibtop_backend *backend, const void
 	glibtop_ppp ppp;
 	int retval = (int) 0;
 	unsigned short _LIBGTOP_demarshal_device;
+	unsigned short _LIBGTOP_demarshal_use_isdn;
 
 	/* variable initialization */
 	memset (&ppp, 0, sizeof (glibtop_ppp));
 	_LIBGTOP_SEND_offset = 0;
 	_LIBGTOP_SEND_ptr = (char *) send_ptr;
 	memset (&_LIBGTOP_demarshal_device, 0, sizeof (unsigned short));
+	memset (&_LIBGTOP_demarshal_use_isdn, 0, sizeof (unsigned short));
 
 	/* send size */
 	_LIBGTOP_SEND_len = 0;
 	_LIBGTOP_SEND_len += sizeof (unsigned short);
+	_LIBGTOP_SEND_len += sizeof (unsigned short);
 	if (_LIBGTOP_SEND_len != send_size)
 		return -GLIBTOP_ERROR_DEMARSHAL_ERROR;
 
@@ -1164,8 +1283,11 @@ _glibtop_demarshal_ppp_i (glibtop *server, glibtop_backend *backend, const void
 	_LIBGTOP_SEND_ptr = (char *) send_ptr + _LIBGTOP_SEND_offset;
 	memcpy (&_LIBGTOP_demarshal_device, _LIBGTOP_SEND_ptr, sizeof (unsigned short));
 	_LIBGTOP_SEND_offset += sizeof (unsigned short);
+	_LIBGTOP_SEND_ptr = (char *) send_ptr + _LIBGTOP_SEND_offset;
+	memcpy (&_LIBGTOP_demarshal_use_isdn, _LIBGTOP_SEND_ptr, sizeof (unsigned short));
+	_LIBGTOP_SEND_offset += sizeof (unsigned short);
 
-	retval = glibtop_get_ppp_p (server, &ppp, _LIBGTOP_demarshal_device);
+	retval = glibtop_get_ppp_p (server, &ppp, _LIBGTOP_demarshal_device, _LIBGTOP_demarshal_use_isdn);
 	if (retval_ptr)
 		*retval_ptr = retval;
 
@@ -1179,142 +1301,189 @@ _glibtop_demarshal_ppp_i (glibtop *server, glibtop_backend *backend, const void
 	return 0;
 }
 
+#endif /* GLIBTOP_SUID_PPP */
+
+
 int
 glibtop_demarshal_func_i (glibtop *server, glibtop_backend *backend, unsigned command, const void *send_ptr, size_t send_size, void *data_ptr, size_t data_size, void **recv_buf_ptr, size_t *recv_size_ptr, void **recv_data_ptr, size_t *recv_data_size_ptr, int *retval_ptr)
 {
 	switch (command) {
+#if GLIBTOP_SUID_CPU
 	case GLIBTOP_CMND_CPU:
 		return _glibtop_demarshal_cpu_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_CPU */
+#if GLIBTOP_SUID_MEM
 	case GLIBTOP_CMND_MEM:
 		return _glibtop_demarshal_mem_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_MEM */
+#if GLIBTOP_SUID_SWAP
 	case GLIBTOP_CMND_SWAP:
 		return _glibtop_demarshal_swap_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_SWAP */
+#if GLIBTOP_SUID_UPTIME
 	case GLIBTOP_CMND_UPTIME:
 		return _glibtop_demarshal_uptime_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_UPTIME */
+#if GLIBTOP_SUID_LOADAVG
 	case GLIBTOP_CMND_LOADAVG:
 		return _glibtop_demarshal_loadavg_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_LOADAVG */
+#if GLIBTOP_SUID_SHM_LIMITS
 	case GLIBTOP_CMND_SHM_LIMITS:
 		return _glibtop_demarshal_shm_limits_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_SHM_LIMITS */
+#if GLIBTOP_SUID_MSG_LIMITS
 	case GLIBTOP_CMND_MSG_LIMITS:
 		return _glibtop_demarshal_msg_limits_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_MSG_LIMITS */
+#if GLIBTOP_SUID_SEM_LIMITS
 	case GLIBTOP_CMND_SEM_LIMITS:
 		return _glibtop_demarshal_sem_limits_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_SEM_LIMITS */
+#if GLIBTOP_SUID_PROCLIST
 	case GLIBTOP_CMND_PROCLIST:
 		return _glibtop_demarshal_proclist_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROCLIST */
+#if GLIBTOP_SUID_PROC_STATE
 	case GLIBTOP_CMND_PROC_STATE:
 		return _glibtop_demarshal_proc_state_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_STATE */
+#if GLIBTOP_SUID_PROC_UID
 	case GLIBTOP_CMND_PROC_UID:
 		return _glibtop_demarshal_proc_uid_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_UID */
+#if GLIBTOP_SUID_PROC_MEM
 	case GLIBTOP_CMND_PROC_MEM:
 		return _glibtop_demarshal_proc_mem_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_MEM */
+#if GLIBTOP_SUID_PROC_TIME
 	case GLIBTOP_CMND_PROC_TIME:
 		return _glibtop_demarshal_proc_time_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_TIME */
+#if GLIBTOP_SUID_PROC_SIGNAL
 	case GLIBTOP_CMND_PROC_SIGNAL:
 		return _glibtop_demarshal_proc_signal_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_SIGNAL */
+#if GLIBTOP_SUID_PROC_KERNEL
 	case GLIBTOP_CMND_PROC_KERNEL:
 		return _glibtop_demarshal_proc_kernel_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_KERNEL */
+#if GLIBTOP_SUID_PROC_SEGMENT
 	case GLIBTOP_CMND_PROC_SEGMENT:
 		return _glibtop_demarshal_proc_segment_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_SEGMENT */
+#if GLIBTOP_SUID_PROC_ARGS
 	case GLIBTOP_CMND_PROC_ARGS:
 		return _glibtop_demarshal_proc_args_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_ARGS */
+#if GLIBTOP_SUID_PROC_MAP
 	case GLIBTOP_CMND_PROC_MAP:
 		return _glibtop_demarshal_proc_map_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PROC_MAP */
+#if GLIBTOP_SUID_INTERFACE_NAMES
 	case GLIBTOP_CMND_INTERFACE_NAMES:
 		return _glibtop_demarshal_interface_names_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_INTERFACE_NAMES */
+#if GLIBTOP_SUID_NETINFO
 	case GLIBTOP_CMND_NETINFO:
 		return _glibtop_demarshal_netinfo_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_NETINFO */
+#if GLIBTOP_SUID_NETLOAD
 	case GLIBTOP_CMND_NETLOAD:
 		return _glibtop_demarshal_netload_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_NETLOAD */
+#if GLIBTOP_SUID_PPP
 	case GLIBTOP_CMND_PPP:
 		return _glibtop_demarshal_ppp_i
 			(server, backend, send_ptr, send_size,
 			 data_ptr, data_size,
 			 recv_buf_ptr, recv_size_ptr,
 			 recv_data_ptr, recv_data_size_ptr, retval_ptr);
+#endif /* GLIBTOP_SUID_PPP */
 	default:
 		return -GLIBTOP_ERROR_INVALID_ARGUMENT;
 	}
