@@ -940,16 +940,16 @@ _glibtop_get_interface_names_c (glibtop *server, glibtop_backend *backend, glibt
 
 #if GLIBTOP_SUID_NETINFO
 
-static int
-_glibtop_get_netinfo_c (glibtop *server, glibtop_backend *backend, glibtop_netinfo *buf,
-                       const char * interface, unsigned transport)
+static glibtop_ifaddr *
+_glibtop_get_netinfo_c (glibtop *server, glibtop_backend *backend, glibtop_array *array, glibtop_netinfo *buf,
+                       const char * interface, u_int64_t transport)
 {
 	unsigned _LIBGTOP_SEND_offset, _LIBGTOP_SEND_len;
 	unsigned _LIBGTOP_DATA_len;
 	unsigned _LIBGTOP_SEND_temp_len;
 	void *_LIBGTOP_SEND_buf, *_LIBGTOP_DATA_buf;
 	char *_LIBGTOP_SEND_ptr, *_LIBGTOP_DATA_ptr;
-	int retval = (int) 0;
+	glibtop_ifaddr * retval = (glibtop_ifaddr *) 0;
 
 	/* variable initialization */
 	_LIBGTOP_SEND_len = 0;
@@ -960,7 +960,7 @@ _glibtop_get_netinfo_c (glibtop *server, glibtop_backend *backend, glibtop_netin
 	/* send size */
 	_LIBGTOP_SEND_len += sizeof (size_t);
 	_LIBGTOP_DATA_len += strlen (interface) + 1;
-	_LIBGTOP_SEND_len += sizeof (unsigned);
+	_LIBGTOP_SEND_len += sizeof (u_int64_t);
 
 	/* send buffer */
 	_LIBGTOP_SEND_buf = glibtop_malloc_r (server, _LIBGTOP_SEND_len+1);
@@ -979,14 +979,14 @@ _glibtop_get_netinfo_c (glibtop *server, glibtop_backend *backend, glibtop_netin
 	_LIBGTOP_DATA_ptr += strlen (interface)+1;
 	_LIBGTOP_SEND_offset += sizeof (size_t);
 	_LIBGTOP_SEND_ptr = (char *) _LIBGTOP_SEND_buf + _LIBGTOP_SEND_offset;
-	memcpy (_LIBGTOP_SEND_ptr, &transport, sizeof (unsigned));
-	_LIBGTOP_SEND_offset += sizeof (unsigned);
+	memcpy (_LIBGTOP_SEND_ptr, &transport, sizeof (u_int64_t));
+	_LIBGTOP_SEND_offset += sizeof (u_int64_t);
 
-	glibtop_call_i (server, backend, GLIBTOP_CMND_NETINFO,
-			_LIBGTOP_SEND_len, _LIBGTOP_SEND_buf,
-			_LIBGTOP_DATA_len, _LIBGTOP_DATA_buf,
-			sizeof (glibtop_netinfo), buf,
-			&retval);
+	retval = glibtop_call_i (server, backend, GLIBTOP_CMND_NETINFO,
+			         _LIBGTOP_SEND_len, _LIBGTOP_SEND_buf,
+			         _LIBGTOP_DATA_len, _LIBGTOP_DATA_buf,
+			         sizeof (glibtop_netinfo), buf,
+			         NULL);
 
 	glibtop_free_r (server, _LIBGTOP_SEND_buf);
 	glibtop_free_r (server, _LIBGTOP_DATA_buf);
@@ -1066,7 +1066,7 @@ _glibtop_get_netload_c (glibtop *server, glibtop_backend *backend, glibtop_netlo
 
 static int
 _glibtop_get_ppp_c (glibtop *server, glibtop_backend *backend, glibtop_ppp *buf,
-                   unsigned short device)
+                   unsigned short device, unsigned short use_isdn)
 {
 	unsigned _LIBGTOP_SEND_offset, _LIBGTOP_SEND_len;
 	unsigned _LIBGTOP_DATA_len;
@@ -1082,6 +1082,7 @@ _glibtop_get_ppp_c (glibtop *server, glibtop_backend *backend, glibtop_ppp *buf,
 
 	/* send size */
 	_LIBGTOP_SEND_len += sizeof (unsigned short);
+	_LIBGTOP_SEND_len += sizeof (unsigned short);
 
 	/* send buffer */
 	_LIBGTOP_SEND_buf = glibtop_malloc_r (server, _LIBGTOP_SEND_len+1);
@@ -1095,6 +1096,9 @@ _glibtop_get_ppp_c (glibtop *server, glibtop_backend *backend, glibtop_ppp *buf,
 	_LIBGTOP_SEND_ptr = (char *) _LIBGTOP_SEND_buf + _LIBGTOP_SEND_offset;
 	memcpy (_LIBGTOP_SEND_ptr, &device, sizeof (unsigned short));
 	_LIBGTOP_SEND_offset += sizeof (unsigned short);
+	_LIBGTOP_SEND_ptr = (char *) _LIBGTOP_SEND_buf + _LIBGTOP_SEND_offset;
+	memcpy (_LIBGTOP_SEND_ptr, &use_isdn, sizeof (unsigned short));
+	_LIBGTOP_SEND_offset += sizeof (unsigned short);
 
 	glibtop_call_i (server, backend, GLIBTOP_CMND_PPP,
 			_LIBGTOP_SEND_len, _LIBGTOP_SEND_buf,
