@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: procmem.h,v 1.14 1999/03/30 14:23:23 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -65,14 +65,14 @@ struct _glibtop_proc_mem
 #define glibtop_get_proc_mem_r		glibtop_get_proc_mem_s
 #endif
 
-void glibtop_get_proc_mem_l (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
+int glibtop_get_proc_mem_l (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_MEM
-void glibtop_init_proc_mem_p (glibtop *server);
-void glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
+int glibtop_init_proc_mem_p (glibtop *server);
+int glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 #else
-void glibtop_init_proc_mem_s (glibtop *server);
-void glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
+int glibtop_init_proc_mem_s (glibtop *server);
+int glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
