@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: procstate.h,v 1.16 1999/03/31 17:34:39 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -85,14 +85,14 @@ struct _glibtop_proc_state
 #define glibtop_get_proc_state_r	glibtop_get_proc_state_s
 #endif
 
-void glibtop_get_proc_state_l (glibtop *server, glibtop_proc_state *buf, pid_t pid);
+int glibtop_get_proc_state_l (glibtop *server, glibtop_proc_state *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_STATE
-void glibtop_init_proc_state_p (glibtop *server);
-void glibtop_get_proc_state_p (glibtop *server, glibtop_proc_state *buf, pid_t pid);
+int glibtop_init_proc_state_p (glibtop *server);
+int glibtop_get_proc_state_p (glibtop *server, glibtop_proc_state *buf, pid_t pid);
 #else
-void glibtop_init_proc_state_s (glibtop *server);
-void glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid);
+int glibtop_init_proc_state_s (glibtop *server);
+int glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid);
 #endif
      
 #ifdef GLIBTOP_NAMES
