@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: proctime.h,v 1.17 1999/04/18 11:47:54 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -82,14 +82,14 @@ struct _glibtop_proc_time
 #define glibtop_get_proc_time_r	glibtop_get_proc_time_s
 #endif
 
-void glibtop_get_proc_time_l (glibtop *server, glibtop_proc_time *buf, pid_t pid);
+int glibtop_get_proc_time_l (glibtop *server, glibtop_proc_time *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_TIME
-void glibtop_init_proc_time_p (glibtop *server);
-void glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf, pid_t pid);
+int glibtop_init_proc_time_p (glibtop *server);
+int glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf, pid_t pid);
 #else
-void glibtop_init_proc_time_s (glibtop *server);
-void glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid);
+int glibtop_init_proc_time_s (glibtop *server);
+int glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
