@@ -87,14 +87,14 @@ struct _glibtop_proc_uid
 #define glibtop_get_proc_uid_r		glibtop_get_proc_uid_s
 #endif
 
-void glibtop_get_proc_uid_l (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
+int glibtop_get_proc_uid_l (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_UID
-void glibtop_init_proc_uid_p (glibtop *server);
-void glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
+int glibtop_init_proc_uid_p (glibtop *server);
+int glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #else
-void glibtop_init_proc_uid_s (glibtop *server);
-void glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
+int glibtop_init_proc_uid_s (glibtop *server);
+int glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
