@@ -22,7 +22,7 @@ _glibtop_missing_feature (glibtop *server, const char *feature,
 	if ((~present & old_required) == 0)
 		return;
 
-	switch (server->error_method) {
+	switch (server->_param.error_method) {
 	case GLIBTOP_ERROR_METHOD_WARN_ONCE:
 		*required &= present;
 	case GLIBTOP_ERROR_METHOD_WARN:
@@ -1141,19 +1141,19 @@ do_return:
 
 }
 
-int
-glibtop_get_netinfo_l (glibtop *server, glibtop_netinfo *buf,
-                       const char * interface, unsigned transport)
+glibtop_ifaddr *
+glibtop_get_netinfo_l (glibtop *server, glibtop_array *array, glibtop_netinfo *buf,
+                       const char * interface, u_int64_t transport)
 {
 	GSList *list;
 	int done = 0;
-	int retval = (int) 0;
+	glibtop_ifaddr * retval = (glibtop_ifaddr *) 0;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_NETINFO), 0);
 
 	if (!server->_priv) {
 		server->glibtop_errno = GLIBTOP_ERROR_NO_BACKEND_OPENED;
-		return -GLIBTOP_ERROR_NO_BACKEND_OPENED;
+		goto do_return;
 	}
 
 	for (list = server->_priv->backend_list;
@@ -1164,7 +1164,7 @@ glibtop_get_netinfo_l (glibtop *server, glibtop_netinfo *buf,
 			continue;
 
 		if (backend->info->call_vector->netinfo) {
-			retval = backend->info->call_vector->netinfo (server, backend, buf, interface, transport);
+			retval = backend->info->call_vector->netinfo (server, backend, array, buf, interface, transport);
 			done = 1;
 			break;
 		}
@@ -1172,14 +1172,7 @@ glibtop_get_netinfo_l (glibtop *server, glibtop_netinfo *buf,
 
 	if (!done) {
 		server->glibtop_errno = GLIBTOP_ERROR_NOT_IMPLEMENTED;
-		return -GLIBTOP_ERROR_NOT_IMPLEMENTED;
-	}
-
-	if (retval < 0) {
-		server->glibtop_errno = -retval;
 		goto do_return;
-	} else {
-		server->glibtop_errno = 0;
 	}
 
 	goto check_missing;
@@ -1253,7 +1246,7 @@ do_return:
 
 int
 glibtop_get_ppp_l (glibtop *server, glibtop_ppp *buf,
-                   unsigned short device)
+                   unsigned short device, unsigned short use_isdn)
 {
 	GSList *list;
 	int done = 0;
@@ -1274,7 +1267,7 @@ glibtop_get_ppp_l (glibtop *server, glibtop_ppp *buf,
 			continue;
 
 		if (backend->info->call_vector->ppp) {
-			retval = backend->info->call_vector->ppp (server, backend, buf, device);
+			retval = backend->info->call_vector->ppp (server, backend, buf, device, use_isdn);
 			done = 1;
 			break;
 		}
