@@ -20,10 +20,10 @@
 /* Space usage statistics for a filesystem.  Blocks are 512-byte. */
 struct fs_usage
 {
-    long fsu_blocks;		/* Total blocks. */
-    long fsu_bfree;		/* Free blocks available to superuser. */
-    long fsu_bavail;		/* Free blocks available to non-superuser. */
-    long fsu_files;		/* Total file nodes. */
-    long fsu_ffree;		/* Free file nodes. */
+    u_int64_t fsu_blocks;	/* Total blocks. */
+    u_int64_t fsu_bfree;	/* Free blocks available to superuser. */
+    u_int64_t fsu_bavail;	/* Free blocks available to non-superuser. */
+    u_int64_t fsu_files;	/* Total file nodes. */
+    u_int64_t fsu_ffree;	/* Free file nodes. */
 };
 
