@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -23,50 +25,74 @@
 
 #include <glibtop/xmalloc.h>
 
+#ifdef LIBGTOP_USE_GLIB_MALLOC
+#include <glib.h>
+#endif
+
 /* Wrappers to malloc, calloc, realloc ... */
 
 void *
 glibtop_malloc_r (glibtop *server, size_t size)
 {
-	void *buf = malloc (size);
+#ifdef LIBGTOP_USE_GLIB_MALLOC
+    return g_malloc0 (size);
+#else
+    void *buf = malloc (size);
 	
-	if (!buf)
-		glibtop_error_io_r (server, "malloc %d bytes", size);
+    if (!buf)
+	glibtop_error_io_r (server, "malloc %d bytes", size);
 	
-	return buf;
+    return buf;
+#endif
 }
 
 void *
 glibtop_calloc_r (glibtop *server, size_t nmemb, size_t size)
 {
-	void *buf = calloc (nmemb, size);
+#ifdef LIBGTOP_USE_GLIB_MALLOC
+    return g_malloc0 (size * nmemb);
+#else
+    void *buf = calloc (nmemb, size);
 	
-	if (!buf)
-		glibtop_error_io_r (server, "calloc %d blocks (%d bytes each)",
-				    nmemb, size);
+    if (!buf)
+	glibtop_error_io_r (server, "calloc %d blocks (%d bytes each)",
+			    nmemb, size);
 	
-	return buf;
+    return buf;
+#endif
 }
 
 void *
 glibtop_realloc_r (glibtop *server, void *ptr, size_t size)
 {
-	void *buf = realloc (ptr, size);
+#ifdef LIBGTOP_USE_GLIB_MALLOC
+    return g_realloc (ptr, size);
+#else
+    void *buf = realloc (ptr, size);
 	
-	if (!buf)
-		glibtop_error_io_r (server, "realloc %d bytes", size);
+    if (!buf)
+	glibtop_error_io_r (server, "realloc %d bytes", size);
 	
-	return buf;
+    return buf;
+#endif
 }
 
 char *
 glibtop_strdup_r (glibtop *server, const char *string)
 {
-	return strcpy (glibtop_malloc_r (server, strlen (string) + 1), string);
+#ifdef LIBGTOP_USE_GLIB_MALLOC
+    return g_strdup (string);
+#else
+    return strcpy (glibtop_malloc_r (server, strlen (string) + 1), string);
+#endif
 }
 
 void
 glibtop_free_r (glibtop *server, const void *ptr)
 {
-	if (ptr) free ((void *) ptr);
+#ifdef LIBGTOP_USE_GLIB_MALLOC
+    g_free (ptr);
+#else
+    if (ptr) free ((void *) ptr);
+#endif
 }
