@@ -53,7 +53,7 @@ static int mib [] = { CTL_KERN, KERN_CLOCKRATE };
 int
 glibtop_init_cpu_p (glibtop *server)
 {
-    if (kvm_nlist (server->_priv->machine.kd, nlst) != 0) {
+    if (kvm_nlist (server->_priv->machine.kd, nlst) < 0) {
 	glibtop_warn_io_r (server, "kvm_nlist (cpu)");
 	return -1;
     }
