@@ -84,7 +84,7 @@ glibtop_init_ppp_p (glibtop *server)
 #endif
 #endif /* HAVE_I4B */
 
-    if (kvm_nlist (server->_priv->machine.kd, nlst) != 0)
+    if (kvm_nlist (server->_priv->machine.kd, nlst) < 0)
 	glibtop_error_io_r (server, "kvm_nlist");
 
     return 0;
@@ -93,7 +93,8 @@ glibtop_init_ppp_p (glibtop *server)
 /* Provides information about ppp usage. */
 
 int
-glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
+glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device,
+		   unsigned short isdn)
 {
 #ifdef HAVE_I4B
 #ifdef HAVE_I4B_ACCT
