@@ -39,7 +39,7 @@ static const unsigned long _glibtop_sysdeps_proc_time_smp =
 /* Init function. */
 
 int
-glibtop_init_proc_time_s (glibtop *server)
+glibtop_init_proc_time_k (glibtop *server)
 {
     server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 
@@ -52,7 +52,7 @@ glibtop_init_proc_time_s (glibtop *server)
 /* Provides detailed information about a process. */
 
 int
-glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf,
+glibtop_get_proc_time_k (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
     libgtop_proc_state_t proc_state;
@@ -60,7 +60,7 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf,
 
     memset (buf, 0, sizeof (glibtop_proc_time));
 
-    retval = glibtop_get_proc_data_proc_state_s (server, &proc_state, pid);
+    retval = glibtop_get_proc_data_proc_state_k (server, &proc_state, pid);
     if (retval)
 	return retval;
 
