@@ -1,4 +1,6 @@
-/* $Id: swap.c,v 1.17 1999/05/06 21:34:46 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -36,11 +38,13 @@ static unsigned long _glibtop_sysdeps_swap_paging =
 
 /* Init function. */
 
-void
+int
 glibtop_init_swap_s (glibtop *server)
 {
-	server->sysdeps.swap = _glibtop_sysdeps_swap |
-		_glibtop_sysdeps_swap_paging;
+    server->sysdeps.swap = _glibtop_sysdeps_swap |
+	_glibtop_sysdeps_swap_paging;
+
+    return 0;
 }
 
 /* Provides information about swap usage. */
@@ -48,57 +52,69 @@ glibtop_init_swap_s (glibtop *server)
 #define MEMINFO		"/proc/meminfo"
 #define PROC_STAT	"/proc/stat"
 
-void
+int
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
-	char buffer [BUFSIZ], *p;
-	int fd, len;
+    char buffer [BUFSIZ], *p;
+    int fd, len;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
+    glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
 
-	memset (buf, 0, sizeof (glibtop_swap));
+    memset (buf, 0, sizeof (glibtop_swap));
 
-	fd = open (MEMINFO, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", MEMINFO);
-
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", MEMINFO);
+    fd = open (MEMINFO, O_RDONLY);
+    if (fd < 0) {
+	glibtop_warn_io_r (server, "open (%s)", MEMINFO);
+	return -1;
+    }
 
+    len = read (fd, buffer, BUFSIZ-1);
+    if (len < 0) {
 	close (fd);
+	glibtop_warn_io_r (server, "read (%s)", MEMINFO);
+	return -1;
+    }
 
-	buffer [len] = '\0';
+    close (fd);
 
-	p = skip_line (buffer);
-	p = skip_line (p);
-	p = skip_token (p);		/* "Swap:" */
+    buffer [len] = '\0';
 
-	buf->total  = strtoul (p, &p, 0);
-	buf->used   = strtoul (p, &p, 0);
-	buf->free   = strtoul (p, &p, 0);
+    p = skip_line (buffer);
+    p = skip_line (p);
+    p = skip_token (p);		/* "Swap:" */
 
-	buf->flags = _glibtop_sysdeps_swap;
+    buf->total  = strtoul (p, &p, 0);
+    buf->used   = strtoul (p, &p, 0);
+    buf->free   = strtoul (p, &p, 0);
 
-	fd = open (PROC_STAT, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", PROC_STAT);
+    buf->flags = _glibtop_sysdeps_swap;
 
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", PROC_STAT);
+    fd = open (PROC_STAT, O_RDONLY);
+    if (fd < 0) {
+	glibtop_warn_io_r (server, "open (%s)", PROC_STAT);
+	return -1;
+    }
 
+    len = read (fd, buffer, BUFSIZ-1);
+    if (len < 0) {
 	close (fd);
+	glibtop_warn_io_r (server, "read (%s)", PROC_STAT);
+	return -1;
+    }
 
-	buffer [len] = '\0';
+    close (fd);
 
-	p = strstr (buffer, "\nswap");
-	if (p == NULL) return;
+    buffer [len] = '\0';
 
-	p = skip_token (p);
+    p = strstr (buffer, "\nswap");
+    if (p == NULL) return 0;
 
-	buf->pagein  = strtoul (p, &p, 0);
-	buf->pageout = strtoul (p, &p, 0);
+    p = skip_token (p);
 
-	buf->flags |= _glibtop_sysdeps_swap_paging;
+    buf->pagein  = strtoul (p, &p, 0);
+    buf->pageout = strtoul (p, &p, 0);
+
+    buf->flags |= _glibtop_sysdeps_swap_paging;
+
+    return 0;
 }
