@@ -1,4 +1,6 @@
-/* $Id: uptime.c,v 1.12 1999/05/06 21:34:48 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,40 +32,49 @@ static unsigned long _glibtop_sysdeps_uptime =
 
 /* Init function. */
 
-void
+int
 glibtop_init_uptime_s (glibtop *server)
 {
-	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+
+    return 0;
 }
 
 /* Provides uptime and idle time. */
 
 #define FILENAME	"/proc/uptime"
 
-void
+int
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
-	char buffer [BUFSIZ], *p;
-	int fd, len;
+    char buffer [BUFSIZ], *p;
+    int fd, len;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
+    glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
 
-	memset (buf, 0, sizeof (glibtop_uptime));
+    memset (buf, 0, sizeof (glibtop_uptime));
 
-	fd = open (FILENAME, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", FILENAME);
-
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", FILENAME);
+    fd = open (FILENAME, O_RDONLY);
+    if (fd < 0) {
+	glibtop_warn_io_r (server, "open (%s)", FILENAME);
+	return -1;
+    }
 
+    len = read (fd, buffer, BUFSIZ-1);
+    if (len < 0) {
 	close (fd);
+	glibtop_warn_io_r (server, "read (%s)", FILENAME);
+	return -1;
+    }
 
-	buffer [len] = '\0';
+    close (fd);
 
-	buf->uptime   = (float) strtod (buffer, &p);
-	buf->idletime = (float) strtod (p, &p);
+    buffer [len] = '\0';
 
-	buf->flags = _glibtop_sysdeps_uptime;
+    buf->uptime   = strtod (buffer, &p);
+    buf->idletime = strtod (p, &p);
+
+    buf->flags = _glibtop_sysdeps_uptime;
+
+    return 0;
 }
