@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: netload.c,v 1.6 1999/03/30 14:29:22 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,9 +27,9 @@
 
 const char *glibtop_names_netload[GLIBTOP_MAX_NETLOAD] =
 {
-    "if_flags", "mtu", "subnet", "address", "packets_in",
-    "packets_out", "packets_total", "bytes_in", "bytes_out",
-    "bytes_total", "errors_in", "errors_out", "errors_total",
+    "packets_in", "packets_out", "packets_total",
+    "bytes_in", "bytes_out", "bytes_total",
+    "errors_in", "errors_out", "errors_total",
     "collisions"
 };
 
@@ -38,16 +38,11 @@ const unsigned glibtop_types_netload[GLIBTOP_MAX_NETLOAD] =
     GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
     GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
     GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
-    GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
-    GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
+    GLIBTOP_TYPE_ULONG
 };
 
 const char *glibtop_labels_netload[GLIBTOP_MAX_NETLOAD] =
 {
-    N_ ("Interface Flags"),
-    N_ ("MTU"),
-    N_ ("Subnet"),
-    N_ ("Address"),
     N_ ("Packets In"),
     N_ ("Packets Out"),
     N_ ("Packets Total"),
@@ -62,10 +57,6 @@ const char *glibtop_labels_netload[GLIBTOP_MAX_NETLOAD] =
 
 const char *glibtop_descriptions_netload[GLIBTOP_MAX_NETLOAD] =
 {
-    N_ ("Interface Flags"),
-    N_ ("Maximum Transfer Unit"),
-    N_ ("Subnet"),
-    N_ ("Address"),
     N_ ("Packets In"),
     N_ ("Packets Out"),
     N_ ("Packets Total"),
