@@ -47,6 +47,8 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_MAP		(1 << GLIBTOP_SYSDEPS_PROC_MAP)
 #define GLIBTOP_SUID_PROC_ARGS		(1 << GLIBTOP_SYSDEPS_PROC_ARGS)
 #define GLIBTOP_SUID_NETLOAD		(1 << GLIBTOP_SYSDEPS_NETLOAD)
+#define GLIBTOP_SUID_NETINFO		(1 << GLIBTOP_SYSDEPS_NETINFO)
+#define GLIBTOP_SUID_INTERFACE_NAMES	(1 << GLIBTOP_SYSDEPS_INTERFACE_NAMES)
 #define GLIBTOP_SUID_PPP		0
 
 END_LIBGTOP_DECLS
