@@ -31,11 +31,11 @@
 BEGIN_LIBGTOP_DECLS
 
 static inline void glibtop_suid_enter (glibtop *server) {
-    setreuid (server->machine.uid, server->machine.euid);
+    setreuid (server->_priv->machine.uid, server->_priv->machine.euid);
 };
 
 static inline void glibtop_suid_leave (glibtop *server) {
-    if (setreuid (server->machine.euid, server->machine.uid))
+    if (setreuid (server->_priv->machine.euid, server->_priv->machine.uid))
 	_exit (1);
 };
 
