@@ -35,12 +35,16 @@ int
 glibtop_init_ppp_s (glibtop *server)
 {
     server->sysdeps.ppp = _glibtop_sysdeps_ppp;
+
+    return 0;
 }
 
 /* Provides PPP/ISDN information. */
 
 int
-glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device)
+glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device,
+		   unsigned short isdn)
 {
     memset (buf, 0, sizeof (glibtop_ppp));
+    return 0;
 }
