@@ -40,6 +40,8 @@ int
 glibtop_init_proclist_p (glibtop *server)
 {
     server->sysdeps.proclist = _glibtop_sysdeps_proclist;
+
+    return 0;
 }
 
 /* How many elements are there per proctable entry? */
@@ -81,7 +83,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	
     memset (buf, 0, sizeof (glibtop_proclist));
 	
-    for (entry = 0; entry < server->machine.proctable_entries;
+    for (entry = 0; entry < server->_priv->machine.proctable_entries;
 	 entry += ELEMENTS_PER_ENTRY)
 	{
 	    /* !!! THE FOLLOWING CODE RUNS SUID ROOT - 
