@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -61,6 +63,14 @@ int glibtop_get_proc_credentials_s(glibtop *, struct prcred *, gid_t *, pid_t);
 /* Reread kstat chains */
 void glibtop_get_kstats(glibtop *);
 
+/* safeio.c */
+
+int s_open (const char *, int);
+int s_stat (const char *, struct stat *);
+int s_close (int);
+ssize_t s_pread (int, void *, size_t, off_t);
+int s_closedir (DIR *);
+
 END_LIBGTOP_DECLS
 
 #endif __GLIBTOP_PRIVATE_H__
