@@ -1,4 +1,6 @@
-/* $Id: procsegment.c,v 1.1.1.1 1999/03/17 18:29:39 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,17 +30,21 @@ static const unsigned long _glibtop_sysdeps_proc_segment = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_segment_s (glibtop *server)
 {
-	server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
+    server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 			    pid_t pid)
 {
-	memset (buf, 0, sizeof (glibtop_proc_segment));
+    memset (buf, 0, sizeof (glibtop_proc_segment));
+
+    return 0;
 }
