@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -29,16 +31,21 @@ static const unsigned long _glibtop_sysdeps_ppp = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_ppp_s (glibtop *server)
 {
-	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
+    server->sysdeps.ppp = _glibtop_sysdeps_ppp;
+
+    return 0;
 }
 
 /* Provides PPP/ISDN information. */
 
-void
-glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device)
+int
+glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device,
+		   unsigned short isdn)
 {
-	memset (buf, 0, sizeof (glibtop_ppp));
+    memset (buf, 0, sizeof (glibtop_ppp));
+
+    return 0;
 }
