@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -28,17 +30,21 @@ static const unsigned long _glibtop_sysdeps_proc_mem = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_mem_s (glibtop *server)
 {
-	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
+    server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf,
 			pid_t pid)
 {
-	memset (buf, 0, sizeof (glibtop_proc_mem));
+    memset (buf, 0, sizeof (glibtop_proc_mem));
+
+    return 0;
 }
