@@ -1,4 +1,6 @@
-/* $Id: procstate.c,v 1.6 1999/02/23 11:46:31 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,17 +30,21 @@ static const unsigned long _glibtop_sysdeps_proc_state = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_state_s (glibtop *server)
 {
-	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
+    server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 			  pid_t pid)
 {
-	memset (buf, 0, sizeof (glibtop_proc_state));
+    memset (buf, 0, sizeof (glibtop_proc_state));
+
+    return 0;
 }
