@@ -1,4 +1,6 @@
-/* $Id: swap.c,v 1.6 1999/02/23 11:46:37 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,16 +30,20 @@ static const unsigned long _glibtop_sysdeps_swap = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_swap_s (glibtop *server)
 {
-	server->sysdeps.swap = _glibtop_sysdeps_swap;
+    server->sysdeps.swap = _glibtop_sysdeps_swap;
+
+    return 0;
 }
 
 /* Provides information about swap usage. */
 
-void
+int
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
-	memset (buf, 0, sizeof (glibtop_swap));
+    memset (buf, 0, sizeof (glibtop_swap));
+
+    return 0;
 }
