@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -28,16 +30,20 @@ static const unsigned long _glibtop_sysdeps_uptime = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_uptime_s (glibtop *server)
 {
-	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+
+    return 0;
 }
 
 /* Provides uptime and idle time. */
 
-void
+int
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
-	memset (buf, 0, sizeof (glibtop_uptime));
+    memset (buf, 0, sizeof (glibtop_uptime));
+
+    return 0;
 }
