@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -31,18 +33,22 @@ static const unsigned long _glibtop_sysdeps_mem = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_mem_p (glibtop *server)
 {
-	server->sysdeps.mem = _glibtop_sysdeps_mem;
+    server->sysdeps.mem = _glibtop_sysdeps_mem;
+
+    return 0;
 }
 
 /* Provides information about memory usage. */
 
-void
+int
 glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 {
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_MEM, 0);
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_MEM, 0);
 	
-	memset (buf, 0, sizeof (glibtop_mem));
+    memset (buf, 0, sizeof (glibtop_mem));
+
+    return 0;
 }
