@@ -44,7 +44,8 @@ glibtop_init_ppp_p (glibtop *server)
 /* Provides PPP/ISDN information. */
 
 int
-glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
+glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device,
+		   unsigned short isdn)
 {
     glibtop_init_p (server, GLIBTOP_SYSDEPS_PPP, 0);
 	
