@@ -1,4 +1,6 @@
-/* $Id: procargs.c,v 1.3 1999/02/23 11:46:53 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,18 +32,19 @@ static const unsigned long _glibtop_sysdeps_proc_args = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_args_p (glibtop *server)
 {
-	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
+    server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-char *
-glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
-			 pid_t pid, unsigned max_len)
+char **
+glibtop_get_proc_args_p (glibtop *server, glibtop_array *array, pid_t pid)
 {
-	memset (buf, 0, sizeof (glibtop_proc_args));
-	return NULL;
+    memset (array, 0, sizeof (glibtop_array));
+    return NULL;
 }
