@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -31,18 +33,22 @@ static const unsigned long _glibtop_sysdeps_uptime = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_uptime_p (glibtop *server)
 {
-	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+
+    return 0;
 }
 
 /* Provides uptime and idle time. */
 
-void
+int
 glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 {
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_UPTIME, 0);
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_UPTIME, 0);
 	
-	memset (buf, 0, sizeof (glibtop_uptime));
+    memset (buf, 0, sizeof (glibtop_uptime));
+
+    return 0;
 }
